import sys
import json

from testwizard.commands_core import CommandBase
from .FindPatternResult import FindPatternResult

class FindPatternCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "FindPattern")
    
    def execute(self, filename, mode):
        if(filename==None):
            raise Exception("filename is required")
        if(mode==None):
            raise Exception("mode is required")

        requestObj = [filename, mode]
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")        

        return FindPatternResult(response.read(), "FindPattern was successful", "FindPattern failed")   


import sys
import json

from testwizard.commands_core import CommandBase
from .SaveFileResult import SaveFileResult

class SaveReferenceBitmapCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "SaveReferenceBitmap")
    
    def execute(self, filename):
        if(filename==None):
            raise Exception("filename is required")

        requestObj = [filename]
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")

        return SaveFileResult(response.read(), "SaveReferenceBitmap was successful", "SaveReferenceBitmap failed")


import sys
import json

from testwizard.commands_core import CommandBase
from .CountLastPatternMatchesResult import CountLastPatternMatchesResult

class CountLastPatternMatchesCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "CountLastPatternMatches")
    
    def execute(self, similarity):
        if(similarity==None):
            raise Exception("similarity is required")

        requestObj = [similarity]
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")

        return CountLastPatternMatchesResult(response.read(), "CountLastPatternMatches was successful", "CountLastPatternMatches failed")   


import json
import sys

from testwizard.commands_core.ResultBase import ResultBase

class WaitForPatternResult(ResultBase):
    def __init__(self, json1, successMessage, failMessage):
        jsonObj = json.loads(json1)
        ResultBase.__init__(self, True if jsonObj["time"] >= 0 and jsonObj["errorCode"] == 0 else False, successMessage, failMessage)

        self.time = jsonObj["time"]
        self.similarity = jsonObj["similarity"]
        self.position = jsonObj["position"]

        if(self.success):
            return

        if("errorCode" in jsonObj):
            self.message = self.getMessageForErrorCode(self.message, jsonObj["errorCode"])


import json
import sys

from testwizard.commands_core.ResultBase import ResultBase

class GetVideoFormatResult(ResultBase):
    def __init__(self, json1, successMessage, failMessage):
        jsonObj = json.loads(json1)
        if("format" in jsonObj):
            self.videoFormat = jsonObj["format"]

        ResultBase.__init__(self, True if jsonObj["format"] else False, successMessage, failMessage)


import json
import sys

from testwizard.commands_core.ResultBase import ResultBase

class FilterResult(ResultBase):
    def __init__(self, json1, successMessage, failMessage):
        jsonObj = json.loads(json1)
        self.success = jsonObj["ok"]
        ResultBase.__init__(self, jsonObj["ok"], successMessage, failMessage)

        if(self.success):
            return

        if("errorCode" in jsonObj):
            self.message = self.getMessageForErrorCode(self.message, jsonObj["errorCode"])


import sys
import json

from testwizard.commands_core import CommandBase
from .FilterResult import FilterResult

class FilterColorBlackWhiteCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "FilterColorBlackWhite")
    
    def execute(self, color, tolerance):
        if(color==None):
            raise Exception("color is required")
        if(tolerance==None):
            raise Exception("tolerance is required")

        requestObj = [color, tolerance]
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")

        return FilterResult(response.read(), "FilterColorBlackWhite was successful", "FilterColorBlackWhite failed")   


import sys
import json

from testwizard.commands_core import CommandBase
from .FilterResult import FilterResult

class FilterCBICommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "FilterCBI")
    
    def execute(self, contrast, brightness, intensity):
        if(contrast==None):
            raise Exception("contrast is required")
        if(brightness==None):
            raise Exception("brightness is required")
        if(intensity==None):
            raise Exception("intensity is required")

        requestObj = [contrast, brightness, intensity]
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")
        
        return FilterResult(response.read(), "FilterCBI was successful", "FilterCBI failed")   


import sys
import json

from testwizard.commands_core import CommandBase
from .WaitForColorResult import WaitForColorResult

class WaitForColorNoMatchCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "WaitForColorNoMatch")
    
    def execute(self, x, y, width, height, refColor, tolerance, minSimilarity, timeout):
        if(x == None):
            raise Exception("x is required")
        if(y == None):
            raise Exception("y is required")
        if(width == None):
            raise Exception("width is required")
        if(height == None):
            raise Exception("height is required")
        if(refColor == None):
            raise Exception("refColor is required")
        if(tolerance == None):
            raise Exception("tolerance is required")
        if(minSimilarity == None):
            raise Exception("minSimilarity is required")    
        if(timeout == None):
            raise Exception("timeout is required")    

        requestObj = [x, y, width, height, refColor, tolerance, minSimilarity, timeout]
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")

        return WaitForColorResult(response.read(), "WaitForColorNoMatch was successful", "WaitForColorNoMatch failed")


import json
import sys

from testwizard.commands_core.ResultBase import ResultBase

class WaitForColorResult(ResultBase):
    def __init__(self, json1, successMessage, failMessage):
        jsonObj = json.loads(json1)
        ResultBase.__init__(self, True if jsonObj["time"] >= 0 and jsonObj["errorCode"] == 0 else False, successMessage, failMessage)

        self.time = jsonObj["time"]
        self.similarity = jsonObj["similarity"]
        if("color" in jsonObj):
            rgbValues = jsonObj["color"].split(',')
            self.color = Color(rgbValues[1], rgbValues[2], rgbValues[3])

        if(self.success):
            return

        if("errorCode" in jsonObj):
            self.message = self.getMessageForErrorCode(self.message, jsonObj["errorCode"])

class Color(object):
    def __init__(self, r, g, b):
       self.r = int(r)
       self.g = int(g)
       self.b = int(b)


import sys
import json

from testwizard.commands_core import CommandBase
from .FindAllPatternLocationsResult import FindAllPatternLocationsResult

class FindAllPatternLocationsCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "FindAllPatternLocations")
    
    def execute(self, filename, mode, similarity):
        if(filename==None):
            raise Exception("filename is required")
        if(mode==None):
            raise Exception("mode is required")
        if(similarity==None):
            raise Exception("similarity is required")

        requestObj = [filename, mode, similarity]
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")

        return FindAllPatternLocationsResult(response.read(), "FindAllPatternLocations was successful", "FindAllPatternLocations failed")


import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult

class StartBackgroundCaptureCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "StartBGCapture")
    
    def execute(self, stepSize, captures):
        if(stepSize==None):
            raise Exception("stepSize is required")
        if(captures==None):
            raise Exception("captures is required")

        requestObj = [stepSize, captures]
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")

        return SimpleResult(response.read(), "StartBackgroundCapture was successful", "StartBackgroundCapture failed")


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="testwizard.commands-video",
    version="3.1.3",
    author="Eurofins Digital Testing - Belgium",
    author_email="support-be@eurofins.com",
    description="Testwizard Video commands",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=['testwizard.commands_video'],
    install_requires=[
        'testwizard.commands-core==3.1.3'
    ],
    classifiers=[
        "Programming Language :: Python :: 3.3",
        "Development Status :: 5 - Production/Stable",
        "Operating System :: OS Independent",
    ],
)





















import sys
import json

from testwizard.commands_core import CommandBase
from .DetectMotionResult import DetectMotionResult

class DetectNoMotionCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "DetectNoMotion")
    
    def execute(self, x, y, width, height, minDifference, timeout, motionDuration = None, tolerance = None, distanceMethod = None, minDistance = None):
        if(x == None):
            raise Exception("x is required")
        if(y == None):
            raise Exception("y is required")
        if(width == None):
            raise Exception("width is required")
        if(height == None):
            raise Exception("height is required")
        if(minDifference == None):
            raise Exception("minDifference is required")
        if(timeout == None):
            raise Exception("timeout is required")

        requestObj = [x, y, width, height, minDifference, timeout]
        if(motionDuration != None):
            requestObj = [x, y, width, height, minDifference, timeout, motionDuration]
            if(tolerance != None):
                requestObj = [x, y, width, height, minDifference, timeout, motionDuration, tolerance]
                if(distanceMethod != None):
                    requestObj = [x, y, width, height, minDifference, timeout, motionDuration, tolerance, distanceMethod]
                    if(minDistance != None):
                        requestObj = [x, y, width, height, minDifference, timeout, motionDuration, tolerance, distanceMethod, minDistance]
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")

        return DetectMotionResult(response.read(), "DetectNoMotion was successful", "DetectNoMotion failed")